%if "%{?distro_section}" == "tainted"
%define include_patented_variants 1
%else
%define include_patented_variants 0
%endif

Name:           xboard
Version:        4.6.2
Release:        %mkrel 5
Summary:        An X Window System graphical chessboard
License:        GPLv3+
Group:          Games/Boards
URL:            http://www.gnu.org/software/xboard
Source0:        http://ftp.gnu.org/gnu/xboard/%{name}-%{version}.tar.gz
Source1:        http://ftp.gnu.org/gnu/xboard/%{name}-%{version}.tar.gz.sig

%if !%{include_patented_variants}
Patch1:         %{name}-4.5.2-mga-remove-patented-chess-variants.patch
%endif
# (kamil) use universal xvt and not xterm for man and info help window
Patch2:         %{name}-4.5.3-mga-replace-xterm-with-xvt.patch

BuildRequires:  texinfo
BuildRequires:  libxt-devel
BuildRequires:  libxaw-devel

Requires:       xorg-x11-fonts

# default chess engine
Suggests:       fairymax
# to play sounds
Suggests:       alsa-utils
# for UCI chess engines
Suggests:       polyglot

Provides:       cmail = %{version}-%{release}

%description
XBoard is a graphical user interface for chess in all its major forms,
including international chess, xiangqi (Chinese chess), shogi (Japanese chess)
and Makruk, in addition to many minor variants such as Losers Chess,
Crazyhouse, Chess960 and Capabanca Chess. It displays a chessboard on the
screen, accepts moves made with the mouse, and loads and saves games in
Portable Game Notation (PGN). It serves as a front-end for many different chess
services, including:
- Chess engines that will run on your machine and play a game against you or
help you analyze, such as GNU Chess, Crafty, or many others.
- Chess servers on the Internet, where you can connect to play chess with
people from all over the world, watch other users play, or just hang out and
chat.
- Correspondence chess played by electronic mail. The CMail program automates
the tasks of parsing email from your opponent, playing his moves out on your
board, and mailing your reply move after you've chosen it.

XBoard runs on Unix and Unix-like systems that use the X Window System. 

XBoard is built with zippy.

%if %include_patented_variants
Gothic Chess is protected by U.S. patent #6,481,716 by Ed Trice.
Falcon Chess is protected by U.S. patent #5,690,334 by George W. Duke
%endif


%prep
%setup -q 

%if !%{include_patented_variants}
%patch1 -p0
%endif
%patch2 -p0

%build
%configure2_5x --bindir=%{_gamesbindir}
%make

%install
%makeinstall bindir=%{buildroot}%{_gamesbindir}

#menu
mv %{buildroot}%{_datadir}/applications/%{name}.desktop %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop

#cmail
install -m 0755 -p cmail %{buildroot}%{_gamesbindir}
(cd %{buildroot}%{_mandir}/man6 && ln -s %{name}.6.* cmail.6.xz)

%find_lang %{name} 

%post
%_install_info %{name}.info

%postun
%_remove_install_info %{name}.info

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING COPYRIGHT NEWS README SHORTLOG TODO zippy.README
%doc *.txt *.html
%{_datadir}/applications/%{_real_vendor}-%{name}.desktop
%{_gamesbindir}/*
%{_mandir}/man?/*
%{_infodir}/*.info*
%{_gamesdatadir}/%{name}/bitmaps/default/*.bm
%{_gamesdatadir}/%{name}/pixmaps/textures/*.xpm
%{_gamesdatadir}/%{name}/sounds/*.wav
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_datadir}/applications/xboard-fen-viewer.desktop
%{_datadir}/applications/xboard-pgn-viewer.desktop
%{_datadir}/applications/xboard-tourney.desktop
%{_datadir}/mime/packages/xboard.xml


%changelog

* Mon Jan 14 2013 umeabot <umeabot> 4.6.2-5.mga3
+ Revision: 386635
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 4.6.2-4.mga3.tainted
+ Revision: 324892
- rebuild for Mga3 Beta1

* Wed Jul 25 2012 kamil <kamil> 4.6.2-3.mga3.tainted
+ Revision: 274361
- suggest polyglot - a chess engine protocol translator

* Mon May 28 2012 kamil <kamil> 4.6.2-2.mga3.tainted
+ Revision: 247734
- drop P0 from this package (again)

* Mon May 28 2012 kamil <kamil> 4.6.2-1.mga3.tainted
+ Revision: 247720
- new version 4.6.2
- rediff P1, P2
- drop P0, it's already announced in GUI and man

* Sat Mar 10 2012 kamil <kamil> 4.5.3-4.mga2.tainted
+ Revision: 222381
- add P2 -mga-replace-xterm-with-xvt.patch (use an universal terminal for man and info window invocation

* Mon Jan 09 2012 kamil <kamil> 4.5.3-3.mga2.tainted
+ Revision: 194245
- fix creation of symlink of the man-page of cmail
- rename patches to fit policies
- clean spec

* Fri Oct 14 2011 kamil <kamil> 4.5.3-2.mga2.tainted
+ Revision: 155273
- xboard suggests alsa-util to play sounds
- xboard requires xorg-x11-fonts (100dpi or 75dpi) instead of only 100dpi
- fairymax (a chess engine) and xterm (x terminal emulator) are now suggested

* Tue Oct 04 2011 kamil <kamil> 4.5.3-1.mga2.tainted
+ Revision: 151546
- New version 4.5.3

* Sat Sep 24 2011 obgr_seneca <obgr_seneca> 4.5.2a-1.mga2.tainted
+ Revision: 147370
- new version 4.5.2a
- now licensed under GPLv3+
- description updated
- requirements updated
- default chess engine updated - changed from GNU Chess (gnuchess) to Fairy-Max (fairymax)
- man page cmail.6* is symliked to the xboard.6* man page
- this package provides cmail
- disable all partly suported board sizes
- SPEC file provided by Kamil Rytarowski
- clean up

* Sun May 15 2011 pterjan <pterjan> 4.2.7-15.mga1
+ Revision: 99043
- Rebuild for fixed find-requires

* Wed Apr 27 2011 wally <wally> 4.2.7-14.mga1
+ Revision: 92042
- fix desktop file name (mga#954)
- drop buildroot definition
- fix exec line in desktop file

* Wed Mar 16 2011 steletch <steletch> 4.2.7-13.mga1
+ Revision: 72896
- Clean spec file
- imported package xboard

